# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AssistantUsageType(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    TEXT = 'text'
    VOICE = 'voice'
    IMAGE_GEN = 'image_gen'
    VIDEO_GEN = 'video_gen'
    AUDIO_GEN = 'audio_gen'
    AUDIO = 'audio'
    CODE_GEN = 'code_gen'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AssistantUsageType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from chat_server_connector_v2.models.chat_message_attachment_create import ChatMessageAttachmentCreate
from chat_server_connector_v2.models.schedulable_message_type import SchedulableMessageType
from chat_server_connector_v2.models.schedule_kind import ScheduleKind
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ScheduledMessageCreate(BaseModel):
    """
    The message add model, extended with a schedule. Message-content rules are inherited from ChatMessageCreate; the schedulable message types are narrowed via the field type, and this validator only checks the schedule fields.
    """ # noqa: E501
    text: Optional[StrictStr] = ''
    file_id: Optional[StrictStr] = None
    chat_message_type: Optional[SchedulableMessageType] = None
    attachments: Optional[List[ChatMessageAttachmentCreate]] = None
    chat_session_id: Optional[StrictInt] = None
    schedule_kind: ScheduleKind
    run_at: Optional[StrictInt] = None
    cron_expr: Optional[StrictStr] = None
    timezone: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["text", "file_id", "chat_message_type", "attachments", "chat_session_id", "schedule_kind", "run_at", "cron_expr", "timezone"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScheduledMessageCreate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScheduledMessageCreate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "text": obj.get("text") if obj.get("text") is not None else '',
            "file_id": obj.get("file_id"),
            "chat_message_type": obj.get("chat_message_type"),
            "attachments": [ChatMessageAttachmentCreate.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "chat_session_id": obj.get("chat_session_id"),
            "schedule_kind": obj.get("schedule_kind"),
            "run_at": obj.get("run_at"),
            "cron_expr": obj.get("cron_expr"),
            "timezone": obj.get("timezone")
        })
        return _obj


